@@ -1,6 +1,6 @@
 package swat;
 
-our $VERSION = 'v0.1.25';
+our $VERSION = 'v0.1.27';
 
 use base 'Exporter'; 
 
@@ -329,6 +329,13 @@ has minimal dependency tree  and probably will run out of the box on most linux
     # developer release might be untested and unstable
     sudo cpanm --mirror-only --mirror https://stratopan.com/melezhik/swat-release/master swat
 
+=head3 install from source
+
+    # useful for contributors
+    perl Makefile.PL
+    make
+    make test
+    make install
 
 Once swat is installed you have B<swat> command line tool to run swat tests, but before do this you need to create them.
 
@@ -481,7 +488,7 @@ There are a I<lot of possibilities>! Please follow L<Test::More|search.cpan.org/
 =head1 Generators
 
 Swat entries generators is the way to I<create new swat entries on the fly>. Technically speaking it's just a perl code which should return an array reference:
-Generators are very close to perl expressions ( generators code is also get evaled ) with maijor difference:
+Generators are very close to perl expressions ( generators code is also get evaled ) with major difference:
 
 Value returned from generator's code should be  array reference. The array is passed back to swat parser so it can create new swat entries from it. 
 
@@ -537,7 +544,7 @@ As an example take a loot at examples/swat-generators-sqlite3 project
 Sometimes code looks more readable when you split it on separate chunks. When swat parser meets  C<\> symbols it postpone entry execution and
 add next line to buffer. This is repeated till no C<\> found on next. Finally swat execute I<"accumulated"> swat entity.
 
-Here are some exmaples:
+Here are some examples:
 
     # Place this in swat data file
     generator:                  \
@@ -601,7 +608,7 @@ thus every swat route maps into Test::More test file with the list of asserts. N
 command is issued to run tests and generate TAP report. That is it.
 
 
-Below is example hwo this looks like
+Below is example how this looks like
 
 =head3 project structure
 
@@ -748,27 +755,27 @@ C<--data-binary> - Post data sending as is.
 =head1 Dynamic routes
 
 There are possibilities to create a undetermined routes using C<:path> placeholders. Let say we have application confirming GET /foo/:whatever 
-requests where :whatevery is arbitrary sting like: GET /foo/one or /foo/two or /foo/baz. Using dynamic routes we could write an swat test for it.
+requests where :whatever is arbitrary sting like: GET /foo/one or /foo/two or /foo/baz. Using dynamic routes we could write an swat test for it.
 
-First let's create difinition for C<`whatever`> path in swat.ini file. This is as simple as create bash variable with a randome sting value:
+First let's create definition for C<`whatever`> path in swat.ini file. This is as simple as create bash variable with a random sting value:
 
 
     # Place this in swat.ini file
     export whatever=`cat /dev/urandom | tr -dc 'a-zA-Z0-9' | fold -w 5  | head -n 1` 
 
 
-Now we should inform swat to use bash varibale $whatever when generating request for /foo/whatever
+Now we should inform swat to use bash variable $whatever when generating request for /foo/whatever
 
 
     $ mkdir foo/:whatever 
 
 
-And finaly drop some check expressions for it:
+And finally drop some check expressions for it:
 
     $ echo 'generator [ $ENV{"whatever"} ]' > foo/:whatever/get.txt
     
 
-Of cousre there are as many dynamic parts in http requests as you need:
+Of course there are as many dynamic parts in http requests as you need:
 
  
     # Place this in swat.ini file
@@ -787,19 +794,19 @@ Swat comes with settings defined in two contexts:
 
 =item *
 
-Environmental Variables
+Environment variables ( session settings )
 
 =item *
 
-swat.ini files
+swat.ini files ( home directory , project based and route based settings  )
 
 
 =back
 
 
-=head2 Environmental Variables
+=head2 Environment variables
 
-Defining a proper environment variables will provide swat settings.
+Following variables define a proper swat settings.
 
 =over
 
@@ -807,11 +814,14 @@ Defining a proper environment variables will provide swat settings.
 
 C<debug> - set to C<1> if you want to see some debug information in output, default value is C<0>
 
-
 =item *
 
 C<debug_bytes> - number of bytes of http response  to be dumped out when debug is on. default value is C<500>
 
+=item *
+
+C<swat_debug> - run swat in debug mode, default value is C<0>
+
 
 =item *
 
@@ -831,7 +841,7 @@ C<curl_params> - additional curl parameters being add to http requests, default
 
 =item *
 
-C<curl_connec_timeout> - follow curl documentation
+C<curl_connect_timeout> - follow curl documentation
 
 
 =item *
@@ -843,6 +853,12 @@ C<curl_max_time> - follow curl documentation
 
 C<port>  - http port of tested host, default value is C<80>
 
+=item *
+
+C<prove_options> - prove options, default value is C<-v>
+
+
+
 
 =back
 
@@ -855,27 +871,27 @@ Swat checks files named C<swat.ini> in the following directories
 
 =item *
 
-B<~/swat.ini>
+B<~/swat.ini> - home directory settings
 
 =item *
 
-B<$project_root_directory/swat.ini>
+B<$project_root_directory/swat.ini> -  project based settings 
 
 =item *
 
-B<$route_directory/swat.ini>
+B<$route_directory/swat.ini> - route based settings 
 
 =back
 
 Here are examples of locations of swat.ini files:
 
 
-     ~/swat.ini # home directory swat.ini file
-     my-app/swat.ini # project_root directory swat.ini file
+     ~/swat.ini # home directory settings 
+     my-app/swat.ini # project based settings
      my-app/hello/get.txt
-     my-app/hello/swat.ini # route directory swat.ini file ( route hello )
+     my-app/hello/swat.ini # route based settings ( route hello )
      my-app/hello/world/get.txt
-     my-app/hello/world/swat.ini # route directory swat.ini file ( route hello/world )
+     my-app/hello/world/swat.ini # route based settings ( route hello/world )
 
 
 Once file exists at any location swat simply B<bash sources it> to apply settings.
@@ -885,44 +901,49 @@ Thus swat.ini file should be bash file with swat variables definitions. Here is
     # the content of swat.ini file:
     curl_params="-H 'Content-Type: text/html'"
     debug=1
-
+    try_num=3
 
 =head2 Settings priority table
 
-Here is the list of settings/contexts  in priority ascending order:
+This table describes order in which settings are applied, statrs from lowest priority settings
 
-    | context                 | location                | priority  level |
-    | ------------------------|------------------------ | --------------- |
-    | swat.ini file           | ~/swat.ini              |               1 |
-    | environmental variables | ---                     |               2 |
-    | swat.ini file           | project root directory  |               3 |
-    | swat.ini file           | route directory         |               4 |
+    | context                 | location                | settings type        | priority  level |
+    | ------------------------|------------------------ | -------------------- | ----------------
+    | swat.ini file           | ~/swat.ini              | home directory       |       1         |
+    | environment variables   | ---                     | session              |       2         |
+    | swat.ini file           | project root directory  | project based        |       3         |
+    | swat.ini file           | route directory         | route based          |       4         |
 
 
-Swat processes settings I<in order>. For every route found swat:
+=head1 Settings merge algorithm
+
+At the very beginning swat apply home directory settings if exist. Then for every route swat settings are applied in order.
+For every new routes swat does following:
 
 =over
 
 =item *
 
-Clear all settings
+Clear a designated set of settings:
+
+    try_num
+    ignore_http_err
+    curl_connect_timeout
+    curl_max_time
+    curl_params
 
 =item *
 
-Apply settings from environmental variables ( if any given )
-
-=item *
-
-Apply settings from swat.ini file in home directory ( if any given )
+Apply environmental settings if exist
 
 
 =item *
 
-Apply settings from swat.ini file in project root directory ( if any given )
+Apply project based settings if exist
 
 =item *
 
-And finally apply settings from swat.ini file in route directory ( if any given )
+And finally apply route based settings if exist
 
 =back
 
@@ -932,7 +953,7 @@ And finally apply settings from swat.ini file in route directory ( if any given
 Swat produces output in L<TAP|https://testanything.org/> format , that means you may use your favorite tap parsers to bring result to
 another test / reporting systems, follow TAP documentation to get more on this. Here is example for converting swat tests into JUNIT format
 
-    swat $project_root $host --formatter TAP::Formatter::JUnit
+    swat <project_root> <host> --formatter TAP::Formatter::JUnit
 
 
 See also L<"Prove settings"> section.
@@ -962,6 +983,18 @@ B<swat_package> - the name of swat package, see L</"Swat Packages"> section
 =back
 
 
+=head2 Default Host
+
+Sometimes it is helpfull to not setup host as command line parameter but define it at $project_root/host file. For example:
+
+
+    # let's create a default host for foo/bar project
+
+    $ cat foo/bar/host
+    foo.bar.com
+
+    $ swat foo/bar/ # will run tests for foo.bar.com
+
 =head1 Prove settings
 
 Swat utilize L<prove utility|http://search.cpan.org/perldoc?prove> to run tests, so all the swat options I<are passed as is to prove utility>.
